gracetools.get_grace_containers_attached_to_leaf
================================================

.. autofunction:: abjad.tools.gracetools.get_grace_containers_attached_to_leaf.get_grace_containers_attached_to_leaf
